@@ -9,11 +9,14 @@
 #include <gnome.h>
 #include <getopt.h>
 
-extern int restarted, just_exit;
-extern int os_x, os_y, os_w, os_h;
-extern struct argp parser;
+#include <global.h>
 
-extern GtkWidget *window;
+BEGIN_GNOME_DECLS
+
+extern int restarted;
+extern GtkAllocation *initial_geometry;
+
+extern const struct poptOption gtop_options [];
 
 int save_state      (GnomeClient        *client,
 		     gint                phase,
@@ -22,10 +25,11 @@ int save_state      (GnomeClient        *client,
 		     GnomeInteractStyle  interact_style,
 		     gint                fast,
 		     gpointer            client_data);
-void connect_client (GnomeClient *client, 
-		     gint         was_restarted, 
-		     gpointer     client_data);
 
-void discard_session (gchar *id);
+gint client_die (GnomeClient *client, gpointer client_data);
+
+int gtop_parse_args (void);
+
+END_GNOME_DECLS
 
 #endif
